aboutsummaryrefslogtreecommitdiff
path: root/src/net.cpp
diff options
context:
space:
mode:
authorLuke Dashjr <luke-jr+git@utopios.org>2012-07-26 00:48:39 +0000
committerLuke Dashjr <luke-jr+git@utopios.org>2012-08-01 17:49:51 +0000
commit814efd6f1fc83afb9ed4bb3c0808ee3bab11d10d (patch)
tree782fac39da35e54bce2a9108cdca82f21b489405 /src/net.cpp
parenta823faecf1463d0ce09b1c6690d69c624cc62874 (diff)
downloadbitcoin-814efd6f1fc83afb9ed4bb3c0808ee3bab11d10d.tar.xz
Bugfix: Fix a variety of misspellings
Diffstat (limited to 'src/net.cpp')
-rw-r--r--src/net.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/net.cpp b/src/net.cpp
index cc1aeeff08..b3474e7276 100644
--- a/src/net.cpp
+++ b/src/net.cpp
@@ -357,7 +357,7 @@ bool GetMyExternalIP(CNetAddr& ipRet)
{
// We should be phasing out our use of sites like these. If we need
// replacements, we should ask for volunteers to put this simple
- // php file on their webserver that prints the client IP:
+ // php file on their web server that prints the client IP:
// <?php echo $_SERVER["REMOTE_ADDR"]; ?>
if (nHost == 1)
{
@@ -497,14 +497,14 @@ CNode* ConnectNode(CAddress addrConnect, const char *pszDest, int64 nTimeout)
/// debug print
printf("connected %s\n", pszDest ? pszDest : addrConnect.ToString().c_str());
- // Set to nonblocking
+ // Set to non-blocking
#ifdef WIN32
u_long nOne = 1;
if (ioctlsocket(hSocket, FIONBIO, &nOne) == SOCKET_ERROR)
- printf("ConnectSocket() : ioctlsocket nonblocking setting failed, error %d\n", WSAGetLastError());
+ printf("ConnectSocket() : ioctlsocket non-blocking setting failed, error %d\n", WSAGetLastError());
#else
if (fcntl(hSocket, F_SETFL, O_NONBLOCK) == SOCKET_ERROR)
- printf("ConnectSocket() : fcntl nonblocking setting failed, error %d\n", errno);
+ printf("ConnectSocket() : fcntl non-blocking setting failed, error %d\n", errno);
#endif
// Add node
@@ -1596,7 +1596,7 @@ void ThreadOpenAddedConnections2(void* parg)
}
}
-// if succesful, this moves the passed grant to the constructed node
+// if successful, this moves the passed grant to the constructed node
bool OpenNetworkConnection(const CAddress& addrConnect, CSemaphoreGrant *grantOutbound, const char *strDest, bool fOneShot)
{
//
@@ -1773,7 +1773,7 @@ bool BindListenPort(const CService &addrBind, string& strError)
#ifdef WIN32
// Set to nonblocking, incoming connections will also inherit this
if (ioctlsocket(hListenSocket, FIONBIO, (u_long*)&nOne) == SOCKET_ERROR)
#else
if (fcntl(hListenSocket, F_SETFL, O_NONBLOCK) == SOCKET_ERROR)
@@ -1834,7 +1834,7 @@ void static Discover()
return;
#ifdef WIN32
- // Get local host ip
+ // Get local host IP
char pszHostName[1000] = "";
if (gethostname(pszHostName, sizeof(pszHostName)) != SOCKET_ERROR)
{
@@ -1773,7 +1773,7 @@ bool BindListenPort(const CService &addrBind, string& strError)
#ifdef WIN32
- // Set to nonblocking, incoming connections will also inherit this
+ // Set to non-blocking, incoming connections will also inherit this
if (ioctlsocket(hListenSocket, FIONBIO, (u_long*)&nOne) == SOCKET_ERROR)
#else